# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
"""quantum-viz.js Widget."""
from quantum_viz.widget import Viewer  # noqa: F401
